@@ -1,5 +1,5 @@
-from ulid_transform import ulid_now, ulid_at_time, ulid_at_time_bytes
 from pytest_codspeed import BenchmarkFixture
+from ulid_transform import ulid_at_time, ulid_at_time_bytes, ulid_now
 
 
 def test_ulid_now(benchmark: BenchmarkFixture) -> None:
